@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigActions.php,v 1.27 2008/01/20 15:09:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigActions.php,v 1.28 2008/06/20 17:41:54 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Action.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigActions.php,v 1.27 2008/01/20 15:09:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigActions.php,v 1.28 2008/06/20 17:41:54 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigActions extends SyL_Config
@@ -66,10 +66,31 @@ class SyL_ConfigActions extends SyL_Config
     /**
      * ǥեȥ᥽å̾
      * 
-     * @access protected
+     * @access private
      * @param string
      */
     var $default_method = 'execute';
+    /**
+     * pre¹ԥ᥽å̾
+     * 
+     * @access private
+     * @param string
+     */
+    var $pre_method = 'preExecute';
+    /**
+     * ڼ¹ԥ᥽å̾
+     * 
+     * @access private
+     * @param string
+     */
+    var $validate_method = 'validate';
+    /**
+     * post¹ԥ᥽å̾
+     * 
+     * @access private
+     * @param string
+     */
+    var $post_method = 'postExecute';
     /**
      * ƥʥ̾
      * 
@@ -97,10 +118,8 @@ class SyL_ConfigActions extends SyL_Config
                 parent::parseXml();
                 // ¹Խѹ
                 $this->changeActionOrder();
-                // ¹ԥ᥽å
-                $this->setPreAction();
-                // ¹ԥ᥽å
-                $this->setPostAction();
+                // 󥤥٥ȥ᥽å
+                $this->setEvents();
                 // 򥭥å岽
                 $cache->write($this->config);
             }
@@ -109,10 +128,8 @@ class SyL_ConfigActions extends SyL_Config
             parent::parseXml();
             // ¹Խѹ
             $this->changeActionOrder();
-            // ¹ԥ᥽å
-            $this->setPreAction();
-            // ¹ԥ᥽å
-            $this->setPostAction();
+            // 󥤥٥ȥ᥽å
+            $this->setEvents();
         }
 
         if (!isset($this->config[$this->action_key])) {
@@ -334,49 +351,41 @@ class SyL_ConfigActions extends SyL_Config
 
 
     /**
-     * ¹᥽åɤ
+     * 󥤥٥ȥ᥽åɤ
      *
      * @access private
      */
-    function setPreAction()
+    function setEvents()
     {
-        $name   = $this->action_key;
-        $method = 'method:pre' . ucfirst($this->default_method);
-        array_splice($this->config[$name]['event'][$this->event], 1, 0, $method);
+        $name = $this->action_key;
+
+        // ᥽åɰ
+        $args = array();
+        $args[0] = 'component:true:data';
+        $args[1] = 'component:true:context';
 
         // ϢνѹΤ¸
-        $main_args = array();
-        foreach ($this->config[$name]['args'] as $key => $arg) {
-            $main_args[$key] = $arg;
-        }
+        $main_args = $this->config[$name]['args'];
 
-        $args = array();
-        $args[0] = 'component:true:data';
-        $args[1] = 'component:true:context';
-
-        // preExecuteΤۤ˸ƤФ褦˽ѹ
+        // 
         $this->config[$name]['args'] = array();
+
+        // preExecute 
+        $method = 'method:' . $this->pre_method;
+        array_splice($this->config[$name]['event'][$this->event], 1, 0, $method);
         $this->config[$name]['args'][$method] = $args;
-        foreach ($main_args as $key => $arg) {
-            $this->config[$name]['args'][$key] = $arg;
-        }
-    }
 
-    /**
-     * ¹Ը᥽åɤ
-     *
-     * @access private
-     */
-    function setPostAction()
-    {
-        $name   = $this->action_key;
-        $method = 'method:post' . ucfirst($this->default_method);
+        // validate 
+        $method = 'method:' . $this->validate_method;
+        array_splice($this->config[$name]['event'][$this->event], 2, 0, $method);
+        $this->config[$name]['args'][$method] = $args;
+
+        // execute 
+        $this->config[$name]['args'] += $main_args;
+
+        // postExecute 
+        $method = 'method:' . $this->post_method;
         array_push($this->config[$name]['event'][$this->event], $method);
-
-        $args = array();
-        $args[0] = 'component:true:data';
-        $args[1] = 'component:true:context';
-
         $this->config[$name]['args'][$method] = $args;
     }
 }
