@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ContextWeb.php,v 1.7 2008/01/20 15:09:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ContextWeb.php,v 1.8 2008/05/21 17:22:47 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once 'SyL_ContextJs.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ContextWeb.php,v 1.7 2008/01/20 15:09:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ContextWeb.php,v 1.8 2008/05/21 17:22:47 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ContextWeb extends SyL_ContextJs
@@ -80,18 +80,24 @@ class SyL_ContextWeb extends SyL_ContextJs
      */
     function SyL_ContextWeb(&$controller, &$data)
     {
-        $router =& SyL_Router::factory($controller, $data, SYL_ROUTER_RULE);
-        $this->setActionFile($router->getActionFile());
-        $this->setClassName($router->getClassName());
-        $this->setActionName($router->getActionName());
-        $this->setTemplateFile($router->getTemplateFile());
-        $view_type = $router->getViewType();
-        if ($view_type !== '') {
-            $this->setViewType($view_type);
-        }
-        $layout_name = $router->getLayoutName();
-        if ($layout_name !== '') {
-            $this->setLayoutName($layout_name);
+        // JSݡȽ
+        if ($data->getImport()) {
+            $this->is_execute = false;
+            $this->setViewType('js.default');
+        } else {
+            $router =& SyL_Router::factory($controller, $data, SYL_ROUTER_RULE);
+            $this->setActionFile($router->getActionFile());
+            $this->setClassName($router->getClassName());
+            $this->setActionName($router->getActionName());
+            $this->setTemplateFile($router->getTemplateFile());
+            $view_type = $router->getViewType();
+            if ($view_type !== '') {
+                $this->setViewType($view_type);
+            }
+            $layout_name = $router->getLayoutName();
+            if ($layout_name !== '') {
+                $this->setLayoutName($layout_name);
+            }
         }
 
         $this->controller =& $controller;
