@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Action.php,v 1.9 2008/06/20 17:41:54 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Action.php,v 1.10 2008/07/10 15:17:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Action.php,v 1.9 2008/06/20 17:41:54 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Action.php,v 1.10 2008/07/10 15:17:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Action
@@ -73,6 +73,15 @@ class SyL_Action
      */
     var $error_messages = array();
 
+    /**
+     * 󥹥ȥ饯
+     *
+     * @access public
+     */
+    function SyL_Action()
+    {
+    }
+
     /**
      * ᥽åɼ¹˼¹Ԥ᥽å
      *
