@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Context.php,v 1.17 2008/03/29 06:11:46 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Context.php,v 1.18 2008/05/21 17:22:47 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -48,7 +48,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Loader.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Context.php,v 1.17 2008/03/29 06:11:46 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Context.php,v 1.18 2008/05/21 17:22:47 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Context
@@ -56,17 +56,17 @@ class SyL_Context
     /**
      * ѥ᡼
      * 
-     * @access private
+     * @access protected
      * @var string
      */
     var $parameters = array();
     /**
-     * ӥ塼
+     * executeե¹ԥե饰
      * 
      * @access protected
-     * @var string
+     * @var bool
      */
-    var $view_type = 'null';
+    var $is_execute = true;
     /**
      * 󥯥饹
      * 
@@ -88,6 +88,13 @@ class SyL_Context
      * @var string
      */
     var $action_file = '';
+    /**
+     * ӥ塼
+     * 
+     * @access protected
+     * @var string
+     */
+    var $view_type = 'null';
     /**
      * ȥ饪֥
      * 
@@ -136,6 +143,17 @@ class SyL_Context
         return $singleton;
     }
 
+    /**
+     * executeե¹Ƚ
+     *
+     * @access public
+     * @return bool executeե¹ԥե饰
+     */
+    function isExecute()
+    {
+        return $this->is_execute;
+    }
+
     /**
      * ǥ쥯ȥ
      *
