@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.32 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.33 2008/05/21 17:22:47 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -69,7 +69,7 @@ define('SYL_CONTROLLER_NAME', 'controller');
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.32 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.33 2008/05/21 17:22:47 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Controller
@@ -362,12 +362,15 @@ class SyL_Controller
      */
     function executeStream()
     {
-        $config_files = array();
-        // ե
-        $config_files['actions'][] = SYL_APP_CONFIG_DIR . "/{$this->action_file_name}";
+        $context =& $this->container->getComponent('context');
+        if ($context->isExecute()) {
+            $config_files = array();
+            // ե
+            $config_files['actions'][] = SYL_APP_CONFIG_DIR . "/{$this->action_file_name}";
 
-        // ٥ȼ¹
-        $this->raiseEvent('executeStream', $config_files);
+            // ٥ȼ¹
+            $this->raiseEvent('executeStream', $config_files);
+        }
     }
 
     /**
