@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_User.php,v 1.4 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_User.php,v 1.5 2008/03/29 06:11:46 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_User.php,v 1.4 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_User.php,v 1.5 2008/03/29 06:11:46 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_User
@@ -54,17 +54,25 @@ class SyL_User
     /**
      * 桼IDѥ᡼̾
      * 
-     * @access private
+     * @access protected
      * @var string
      */
-    var $userid_parameter_name = 'login_username';
+    var $userid_param_name = 'login_username';
     /**
      * ѥɥѥ᡼̾
      * 
-     * @access private
+     * @access protected
      * @var string
      */
-    var $password_parameter_name = 'login_password';
+    var $password_param_name = 'login_password';
+    /**
+     * ǧڻΥѥɥϥåˡ
+     * array(CLIENT¦HASHˡ, SERVER¦HASHˡ)
+     * 
+     * @access protected
+     * @var string
+     */
+    var $password_hash = array(null,null);
 
     /**
      * 󥹥ȥ饯
@@ -114,9 +122,9 @@ class SyL_User
      * @access public
      * @return string 桼IDѥ᡼̾
      */
-    function getUserIdParamaterName()
+    function getUserIdParamName()
     {
-        return $this->userid_parameter_name;
+        return $this->userid_param_name;
     }
 
     /**
@@ -125,9 +133,20 @@ class SyL_User
      * @access public
      * @return string ѥɥѥ᡼̾
      */
-    function getPasswordParamaterName()
+    function getPasswordParamName()
     {
-        return $this->password_parameter_name;
+        return $this->password_param_name;
+    }
+
+    /**
+     * ǧڻΥѥɥϥåˡ򥻥å
+     * 
+     * @access public
+     * @return array ǧڻΥѥɥϥåˡ
+     */
+    function getPasswordHash()
+    {
+        return $this->password_hash;
     }
 
     /**
