@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewJsLogin.php,v 1.5 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewJsLogin.php,v 1.6 2008/02/02 14:40:44 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -48,7 +48,7 @@ require_once 'SyL_ViewJs.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewJsLogin.php,v 1.5 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewJsLogin.php,v 1.6 2008/02/02 14:40:44 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ViewJsLogin extends SyL_ViewJs
@@ -65,16 +65,16 @@ class SyL_ViewJsLogin extends SyL_ViewJs
 
         list($username, $password) = explode(':', SYL_AUTH_LOGIN_PARAMETER);
         if (SYL_AUTH_PASSWORD_HASH) {
-            $this->js->set('login_key',  $this->auth->createChallengeCode());
-            $this->js->set('login_hash', 'hex_' . SYL_AUTH_PASSWORD_HASH);
-            $this->js->import('hash.' . SYL_AUTH_PASSWORD_HASH);
+            $this->data->set('login_key',  $this->auth->createChallengeCode());
+            $this->data->set('login_hash', 'hex_' . SYL_AUTH_PASSWORD_HASH);
+            $this->data->addImport('hash.' . SYL_AUTH_PASSWORD_HASH);
         } else {
-            $this->js->set('login_key',  '');
-            $this->js->set('login_hash', 'null');
+            $this->data->set('login_key',  '');
+            $this->data->set('login_hash', 'null');
         }
-        $this->js->import('login');
-        $this->js->set('login_username', $username);
-        $this->js->set('login_password', $password);
+        $this->data->addImport('login');
+        $this->data->set('login_username', $username);
+        $this->data->set('login_password', $password);
     }
 
 }
