@@ -30,9 +30,8 @@ SyL.Ajax.Process = function()
 SyL.Ajax.Process.prototype = {
   initialize: function()
   {
-    var self = this;
-    var method      = 'GET';
-    var async       = true;
+    var method = 'GET';
+    var async  = true;
     var loadingCallback = null;
     var completeCallback  = null;
     var timeoutCallback  = null;
@@ -41,6 +40,9 @@ SyL.Ajax.Process.prototype = {
     var parameters  = {};
     var request     = getXMLHttpObject();
     var timeout     = 30000;
+    var timeoutTimer = null;
+
+    var self = this;
 
     this.setMethod = function(methodt)
     {
@@ -233,9 +235,26 @@ SyL.Ajax.Process.prototype = {
           completeCallback = eval('(' + completeCallback + ')');
         }
 
-        request.onreadystatechange = function() {onReadyStateChange(request);};
+        var timeoutTimer = null;
+        request.onreadystatechange = function(e) {
+          onReadyStateChange(request);
+          if (timeoutTimer) {
+            clearTimeout(timeoutTimer);
+            timeoutTimer = null;
+          }
+          return false;
+        };
 
-        if (timeout > 0) requestTimeout(timeout);
+        if (timeout > 0) {
+          timeoutTimer = setTimeout(function(){
+            clearTimeout(timeoutTimer);
+            timeoutTimer = null;
+            self.cancelRequest();
+            if (timeoutCallback) {
+              timeoutCallback();
+            }
+          }, timeout);
+        }
 
         if (method == 'POST') {
           request.open(method, url, async);
@@ -295,16 +314,6 @@ SyL.Ajax.Process.prototype = {
       }
     };
 
-    function requestTimeout(timeout)
-    {
-      var timer = setInterval(function(){
-        clearInterval(timer);
-        self.cancelRequest();
-        if (timeoutCallback) {
-          timeoutCallback();
-        }
-      }, timeout);
-    };
     this.cancelRequest = function()
     {
       if (typeof(request) == "object") {
