@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Console.php,v 1.7 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Console.php,v 1.8 2008/07/10 15:17:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,38 +39,24 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Console.php,v 1.7 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Console.php,v 1.8 2008/07/10 15:17:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Console
 {
     /**
-     * ɸ
+     * Ƭ
      *
      * @access private
-     * @var resource
+     * @var string
      */
-    var $stdin;
-    /**
-     * ɸ
-     *
-     * @access private
-     * @var resource
-     */
-    var $stdout;
-    /**
-     * ɸ२顼
-     *
-     * @access private
-     * @var resource
-     */
-    var $stderr;
+    var $shell_prefix = '> ';
     /**
      * ȤƼ¹ԤȤΰ
      * falseξϥޥɼ¹Բ
      *
      * @access private
-     * @var array
+     * @var string
      */
     var $shell_string = '\!';
     /**
@@ -106,21 +92,66 @@ class SyL_Console
      * @var array
      */
     var $callback_func = array();
+    /**
+     * ɽѴ󥳡
+     *
+     * @access private
+     * @var array
+     */
+    var $output_encode = '';
+    /**
+     * ץ¦Υ󥳡
+     * 
+     * @access protected
+     * @var string
+     */
+    var $internal_encode = '';
 
     /**
      * 󥹥ȥ饯
      *
      * @access public
+     * @param string ɽѴ󥳡
+     * @param string ץ¦󥳡
      */
     function SyL_Console()
     {
-        $this->stdin  = fopen('php://stdin',  'r');
-        $this->stdout = fopen('php://stdout', 'w');
-        $this->stderr = fopen('php://stderr', 'w');
-
         $this->callback_func = array(&$this, 'doCallback');
     }
 
+    /**
+     * Ƭ򥻥åȤ
+     *
+     * @access public
+     * @param string Ƭ
+     */
+    function setShellPrefix($shell_prefix)
+    {
+        $this->shell_prefix = $shell_prefix;
+    }
+
+    /**
+     * ɽѴ󥳡ɤ򥻥åȤ
+     *
+     * @access public
+     * @param string ɽѴ󥳡
+     */
+    function setOutputEncode($output_encode)
+    {
+        $this->output_encode = $output_encode;
+    }
+
+    /**
+     * ץ¦󥳡ɤ򥻥åȤ
+     *
+     * @access public
+     * @param string ץ¦󥳡
+     */
+    function setInternalEncode($internal_encode)
+    {
+        $this->internal_encode = $internal_encode;
+    }
+
     /**
      * λʸɲä
      *
@@ -151,7 +182,7 @@ class SyL_Console
      * @param string ɽå
      * @param string ޥ­å
      */
-    function setMessage($message, $message_default='')
+    function addMessage($message, $message_default='')
     {
         $this->command_messages[] = array($message, $message_default);
     }
@@ -190,7 +221,7 @@ class SyL_Console
     function start($loop=false)
     {
         while (true) {
-            $shell = false;
+            $shell = '';
             if ($this->command_messages) {
                 $command_message = array_shift($this->command_messages);
                 $return = $this->getInput($command_message[0], $command_message[1]);
@@ -204,8 +235,7 @@ class SyL_Console
                 break;
             }
             if ($this->shell_string && (substr($return, 0, strlen($this->shell_string)) == $this->shell_string)) {
-                $shell = true;
-                $return = shell_exec(substr($return, strlen($this->shell_string)));
+                $shell = shell_exec(substr($return, strlen($this->shell_string)));
             }
             // Хåؿ¹
             call_user_func_array($this->callback_func, array(&$this, $return, $shell));
@@ -221,10 +251,7 @@ class SyL_Console
      */
     function stdout($message, $newline=true)
     {
-       if ($newline) {
-           $message .= "\n";
-       }
-       fwrite($this->stdout, $message);
+        $this->stdmessage($message, 'out', $newline);
     }
 
     /**
@@ -236,10 +263,35 @@ class SyL_Console
      */
     function stderr($message, $newline=true)
     {
-       if ($newline) {
-           $message .= "\n";
-       }
-       fwrite($this->stderr, $message);
+        $this->stdmessage($message, 'err', $newline);
+    }
+
+    /**
+     * ɽϤ
+     *
+     * @access public
+     * @param string ɽå
+     * @param string ɽ
+     * @param bool ԥե饰
+     */
+    function stdmessage($message, $type='out', $newline=true)
+    {
+        if ($this->output_encode) {
+            if ($this->internal_encode) {
+                $message = mb_convert_encoding($message, $this->output_encode, $this->internal_encode);
+            } else {
+                $message = mb_convert_encoding($message, $this->output_encode);
+            }
+        }
+        if ($newline) {
+            $message .= "\n";
+        }
+        if ($type == 'err') {
+            fwrite(STDERR, $message);
+        } else {
+            fwrite(STDOUT, $message);
+        }
+        ob_flush();
     }
 
     /**
@@ -254,16 +306,15 @@ class SyL_Console
         if ($message_default != '') {
             $message_default .= ' ';
         }
-        $message_default .= '> ';
+        $message_default .= $this->shell_prefix;
         if ($message) {
             $this->stdout($message);
         }
         $this->stdout($message_default, false);
-
         ob_flush();
-        return trim(fgets($this->stdin,256));
+
+        return trim(fgets(STDIN,256));
     }
-    
 }
 
 ?>
