@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_UtilUseragent.php,v 1.9 2008/05/21 17:22:47 seasonstream Exp $
+ * @version   CVS: $Id: SyL_UtilUseragent.php,v 1.10 2008/06/20 17:41:54 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_UtilUseragent.php,v 1.9 2008/05/21 17:22:47 seasonstream Exp $
+ * @version   CVS: $Id: SyL_UtilUseragent.php,v 1.10 2008/06/20 17:41:54 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_UtilUserAgent
@@ -59,50 +59,56 @@ class SyL_UtilUserAgent
      * @var array
      */
     var $platforms = array(
-      'Windows NT 6.0'  => 'Windows Vista',
-      'Windows NT 5.2'  => 'Windows 2003 or XP x64',
-      'Windows NT 5.1'  => 'Windows XP',
-      'Windows NT 5.01' => 'Windows 2000 (Service Pack 1)',
-      'Windows NT 5.0'  => 'Windows 2000',
+      'Windows NT 6\.0' => 'Windows Vista',
+      'Windows NT 5\.2' => 'Windows 2003 or XP x64',
+      'Windows NT 5\.1' => 'Windows XP',
+      'Windows NT 5\.0' => 'Windows 2000',
       'Windows 2000'    => 'Windows 2000',
-      'Windows NT 4.0'  => 'Windows NT 4.0',
-      'winnt4.0'        => 'Windows NT 4.0',
-      'winnt 4.0'       => 'Windows NT 4.0',
+      'Windows NT 4\.0' => 'Windows NT 4.0',
+      'winnt[ ]?4\.0'   => 'Windows NT 4.0',
       'winnt'           => 'Windows NT',
-      'windows 98'      => 'Windows 98',
-      'win98'           => 'Windows 98',
-      'windows 95'      => 'Windows 95',
-      'win95'           => 'Windows 95',
+      'windows (9[58])' => 'Windows {$1}',
+      'win(9[58])'      => 'Windows {$1}',
+      'Win 9x 4\.9'     => 'Windows Me',
       'windows ce'      => 'Windows CE',
       'windows'         => 'Unknown Windows OS',
-      'mac os x'        => 'Mac OS X',
-      'mac os'          => 'Mac OS',
-      'ppc mac'         => 'Mac OS',
-      'Macintosh'       => 'Mac OS',
-      'FreeBSD'         => 'FreeBSD',
-      'Debian'          => 'Debian Linux',
-      'SunOS'           => 'Sun Solaris',
-      'beos'            => 'BeOS',
-      'Asianux'         => 'Asianux',
-      'hp-ux'           => 'HP-UX',
-      'netbsd'          => 'NetBSD',
-      'openbsd'         => 'OpenBSD',
+      'Mac OS X ([0-9]+)_([0-9]+)' => 'Mac OS X {$1}.{$2}',
+      'Mac OS X ([0-9\.]+)' => 'Mac OS X {$1}',
+      'Mac OS X'  => 'Mac OS X',
+      'Mac OS'    => 'Mac OS',
+      'ppc mac'   => 'Mac OS',
+      'Macintosh' => 'Mac OS',
+      'Debian package ([0-9\.]+)' => 'Debian GNU/Linux {$1}',
+      'Debian.+etch'  => 'Debian GNU/Linux 4.0',
+      'Debian.+sarge' => 'Debian GNU/Linux 3.1',
+      'Debian.+woody' => 'Debian GNU/Linux 3.0',
+      'Debian'        => 'Debian GNU/Linux',
+      'Fedora\/[0-9\-\.]+fc([0-9]+)' => 'Fedora Core {$1}',
+      'Remi\/[0-9\-\.]+fc([0-9]+)' => 'Fedora Core {$1}',
       'Fedora'          => 'Fedora Core',
+      'CentOS\/[0-9\-\.]+el([0-9]+)' => 'CentOS {$1}',
       'CentOS'          => 'CentOS',
-      'Ubuntu'          => 'Ubuntu Linux',
-      'Mandriva'        => 'Mandriva Linux',
+      'Red Hat\/[0-9\-\.]+el([0-9]+)' => 'Red Hat Linux {$1}',
       'Red Hat'         => 'Red Hat Linux',
-      'aix'             => 'AIX',
-      'irix'            => 'Irix',
-      'gnu'             => 'GNU/Linux',
-      'vine'            => 'Vine Linux',
-      'linux'           => 'Linux',
-      'unix'            => 'Unknown Unix OS',
+      'Ubuntu\/([0-9\.]+)' => 'Ubuntu Linux {$1}',
+      'Ubuntu'          => 'Ubuntu Linux',
+      'Vine\/[0-9\-\.]+vl([0-9]+)' => 'Vine Linux {$1}',
+      'VineLinux\/[0-9\-\.]+vl([0-9]+)' => 'Vine Linux {$1}',
+      'Vine'            => 'Vine Linux',
+      'Asianux\/[0-9\-\.]+el([0-9]+)' => 'Asianux {$1}',
+      'Asianux'         => 'Asianux',
+      'Mandriva\/[0-9\-\.]+mdv([0-9\.]+)' => 'Mandriva Linux {$1}',
+      'Mandriva' => 'Mandriva Linux',
+      'SUSE'     => 'SUSE Linux',
+      'SunOS'    => 'Sun Solaris',
+      'gnu'      => 'GNU/Linux',
+      'linux'    => 'Linux',
+      'unix'     => 'Unknown Unix OS',
 
       'Nintendo Wii'     => 'Wii',
       'PS2; PlayStation' => 'PlayStation 2',
       'PLAYSTATION 3'    => 'PlayStation 3',
-      'Dreampassport'    => 'DreamCast'
+      'Dreampassport'    => 'DreamCast',
     );
 
     /**
@@ -112,42 +118,40 @@ class SyL_UtilUserAgent
      * @var array
      */
     var $browsers = array(
-      'Opera'             => 'Opera',
-      'Lunascape'         => 'Lunascape',
-      'Sleipnir'          => 'Sleipnir',
-      'MSIE'              => 'Internet Explorer',
-      'Internet Explorer' => 'Internet Explorer',
-      'Shiira'            => 'Shiira',
-      'Sylera'            => 'Sylera',
-      'Firefox'           => 'Firefox',
-      'Firebird'          => 'Firebird(Firefox)',
-      'Chimera'           => 'Chimera',
-      'Phoenix'           => 'Phoenix',
-      'Camino'            => 'Camino',
-      'Netscape'          => 'Netscape',
-      'Safari'            => 'Safari',
-      'IBrowse'           => 'IBrowse',
-      'icab'              => 'iCab',
-      'Konqueror'         => 'Konqueror',
-      'hotjava'           => 'HotJava',
-      'Lynx'              => 'Lynx',
-      'jig browser'       => 'jig browser',
-      'Iceweasel'         => 'Iceweasel',
-      'Galeon'            => 'Galeon',
+      'Lunascape ([0-9\.]+)'  => 'Lunascape {$1}',
+      'Sleipnir\/([0-9\.]+)'  => 'Sleipnir {$1}',
+      'MSIE ([0-9\.]+)'       => 'Internet Explorer {$1}',
+      'Iceweasel\/([0-9\.]+)' => 'Iceweasel {$1}',
+      'Epiphany\/([0-9\.]+)'  => 'Epiphany {$1}',
+      'Firefox\/([0-9\.]+)'   => 'Firefox {$1}',
+      'Opera[ \/]([0-9\.]+) ' => 'Opera {$1}',
+      'Safari\/85\.' => 'Safari 1.0',
+      'Safari\/100'  => 'Safari 1.1',
+      'Safari\/125'  => 'Safari 1.2',
+      'Safari\/312'  => 'Safari 1.3',
+      'Safari\/41\d' => 'Safari 2.0',
+      'Safari\/523'  => 'Safari 3.0',
+      'Safari\/525'  => 'Safari 3.1',
+      'Sylera\/([0-9\.]+)'    => 'Sylera {$1}',
+      'SeaMonkey\/([0-9\.]+)' => 'SeaMonkey {$1}',
+      'Camino\/([0-9\.]+)'    => 'Camino {$1}',
+      'Netscape\d?\/([0-9\.]+)' => 'Netscape {$1}',
+      'Galeon\/([0-9\.]+)'    => 'Galeon {$1}',
+      'Konqueror\/([0-9\.]+)' => 'Konqueror {$1}',
+      'Lynx\/([0-9\.]+)'      => 'Lynx {$1}',
+      'jig browser' => 'jig browser',
+      'hotjava'     => 'HotJava',
+      'icab'        => 'iCab',
 
-      'sharp pda browser' => 'ZAURUS',
-      'AVE-Front'         => 'AVE-Front',
-      'NetFront'          => 'NetFront',
-      'UP.Browser'        => 'UP.Browser',
-      'L-mode'            => 'L-mode',
+      'NetFront'    => 'NetFront',
+      'UP\.Browser' => 'UP.Browser',
+      'L\-mode'     => 'L-mode',
+      'AVE\-Front'  => 'AVE-Front',
 
-      'Dreampassport'     => 'Dreampassport',
+      'Dreampassport' => 'Dreampassport',
 
-      'OmniWeb'           => 'OmniWeb',
-      'WebCapture'        => 'Adobe Acrobat',
-      'Mozilla'           => 'Mozilla',
-      'W3C'               => 'W3C Validator',
-      'Wget'              => 'Wget'
+      'OmniWeb' => 'OmniWeb',
+      'Mozilla' => 'Mozilla'
     );
 
     /**
@@ -176,25 +180,24 @@ class SyL_UtilUserAgent
      * @var array
      */
     var $robots = array(
-      'Googlebot-Image'  => 'Googlebot-Image',
-      'Googlebot-Mobile' => 'Googlebot-Mobile',
-      'Googlebot'        => 'Googlebot',
-      'Yahoo-MMCrawler'  => 'Yahoo-MMCrawler',
-      'Yahoo! Slurp'     => 'Yahoo! Slurp',
-      'Y!J-'             => 'Y!J',
-      'msnbot-NewsBlogs' => 'msnbot-NewsBlogs',
-      'msnbot-media'     => 'msnbot-media',
-      'msnbot'           => 'msnbot',
-      'Yeti'             => 'YetiBot',
-      'Baiduspider'      => 'Baiduspider',
-      'boitho.com-dc'    => 'boitho.com-dc',
-      'blogoonbot'       => 'blogoonbot',
-      'Comaneci_bot'     => 'Comaneci_bot',
-      'e-SocietyRobot'   => 'e-SocietyRobot',
-      'Gaisbot'          => 'Gaisbot',
-      'GurujiBot'        => 'GurujiBot',
-      'ICC-Crawler'      => 'ICC-Crawler',
-      'ichiro'           => 'ichiro',
+      'Googlebot\-Image'  => 'Googlebot-Image',
+      'Googlebot\-Mobile\/([0-9\.]+)' => 'Googlebot-Mobile {$1}',
+      'Googlebot\/([0-9\.]+)' => 'Googlebot {$1}',
+      'Yahoo\-MMCrawler'  => 'Yahoo-MMCrawler',
+      'Yahoo! Slurp'      => 'Yahoo! Slurp',
+      'Y!J\-'             => 'Y!J',
+      'msnbot\-NewsBlogs' => 'msnbot-NewsBlogs',
+      'msnbot\-media\/([0-9\.]+)' => 'msnbot-media {$1}',
+      'msnbot\/([0-9\.]+)' => 'msnbot {$1}',
+      'Yeti\/([0-9\.]+)'   => 'YetiBot {$1}',
+      'Baiduspider'        => 'Baiduspider',
+      'ichiro\/([0-9\.]+)' => 'ichiro {$1}',
+      'blogoonbot'      => 'blogoonbot',
+      'Comaneci_bot'    => 'Comaneci_bot',
+      'e\-SocietyRobot' => 'e-SocietyRobot',
+      'Gaisbot'         => 'Gaisbot',
+      'GurujiBot'       => 'GurujiBot',
+      'ICC\-Crawler'    => 'ICC-Crawler',
       'InfoSeek Sidewinder' => 'InfoSeek Sidewinder',
       'IDBot'         => 'IDBot',
       'IRLbot'        => 'IRLbot',
@@ -217,7 +220,6 @@ class SyL_UtilUserAgent
       'SurveyBot'     => 'SurveyBot',
       'YodaoBot'      => 'YodaoBot',
       'TurnitinBot'   => 'TurnitinBot',
-      'Twiceler-'     => 'Twiceler',
       'Vajradhara'    => 'Vajradhara',
       'WebGenBot'     => 'WebGenBot'
     );
@@ -271,15 +273,7 @@ class SyL_UtilUserAgent
      */
     function getPlatform()
     {
-        foreach ($this->platforms as $key => $value) {
-            $reg = '/' . preg_quote($key, '/') . '[ |\/]?([0-9\.]+)?([ |;])?.*/i';
-            if (preg_match($reg, $this->user_agent, $matches)) {
-            //if (stristr($this->user_agent, $key) !== false) {
-                return isset($matches[1]) ? $value . ' ' . $matches[1] : $value;
-                //return $value;
-            }
-        }
-        return null;
+        return $this->getUserAgent($this->platforms);
     }
 
     /**
@@ -290,13 +284,7 @@ class SyL_UtilUserAgent
      */
     function getBrowser()
     {
-        foreach ($this->browsers as $key => $value) {
-            $reg = '/' . preg_quote($key, '/') . '[ |\/]?([0-9a-zA-Z\-\.\/]+)?[ |;]?.*/i';
-            if (preg_match($reg, $this->user_agent, $matches)) {
-                return isset($matches[1]) ? $value . ' ' . $matches[1] : $value;
-            }
-        }
-        return null;
+        return $this->getUserAgent($this->browsers);
     }
 
     /**
@@ -307,12 +295,7 @@ class SyL_UtilUserAgent
      */
     function getCarrier()
     {
-        foreach ($this->carriers as $key => $value) {
-            if (stristr($this->user_agent, $key) !== false) {
-                return $value;
-            }
-        }
-        return null;
+        return $this->getUserAgent($this->carriers);
     }
 
     /**
@@ -376,10 +359,24 @@ class SyL_UtilUserAgent
      */
     function getRobot()
     {
-        foreach ($this->robots as $key => $value) {
-            $reg = '/' . preg_quote($key, '/') . '[ |\/]?([0-9\.\/]+)?.*/i';
-            if (preg_match($reg, $this->user_agent, $matches)) {
-                return isset($matches[1]) ? $value . ' ' . $matches[1] : $value;
+        return $this->getUserAgent($this->robots);
+    }
+
+    /**
+     * ̥桼ȼå
+     *
+     * @access private
+     * @param array ̥桼Ƚ
+     * @return string ̥桼
+     */
+    function getUserAgent($env)
+    {
+        foreach ($env as $key => $value) {
+            if (preg_match("/{$key}/i", $this->user_agent, $matches)) {
+                for ($i=1; $i<count($matches); $i++) {
+                    $value = str_replace('{$'.$i.'}', $matches[$i], $value);
+                }
+                return $value;
             }
         }
         return null;
