@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ValidationValidatorFile.php,v 1.4 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ValidationValidatorFile.php,v 1.5 2008/05/21 17:22:47 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ValidationValidatorFile.php,v 1.4 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ValidationValidatorFile.php,v 1.5 2008/05/21 17:22:47 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ValidationValidatorFile extends SyL_ValidationValidator
@@ -181,11 +181,9 @@ class SyL_ValidationValidatorFile extends SyL_ValidationValidator
             $options[] = "'max_valids': '{$this->max_valids}'";
 
             $js  = '';
-            $js .= 'if (!error_message) {' . "\n";
-            $js .= '  var error_message_tmp = validation.isRegex(element_name, "' . $error_message . '", {' . implode(',', $options) . '});' . "\n";
-            $js .= '  if (error_message_tmp) {' . "\n";
-            $js .= '    error_message = error_message_tmp;' . "\n";
-            $js .= '  }' . "\n";
+            $js .= 'var message_tmp = validation.isRegex(name, "' . $error_message . '", {' . implode(',', $options) . '});' . "\n";
+            $js .= 'if (message_tmp) {' . "\n";
+            $js .= '  message = message_tmp;' . "\n";
             $js .= '}' . "\n";
         }
         return $js;
