@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: Index.php,v 1.5 2008/05/21 17:22:47 seasonstream Exp $
+ * @version   CVS: $Id: Index.php,v 1.6 2008/07/10 15:17:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -48,7 +48,7 @@ SyL_Loader::lib('File');
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: Index.php,v 1.5 2008/05/21 17:22:47 seasonstream Exp $
+ * @version   CVS: $Id: Index.php,v 1.6 2008/07/10 15:17:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class Index extends AppAction
@@ -78,77 +78,57 @@ class Index extends AppAction
     function execute(&$data, &$context)
     {
         $cmd =& $context->getConsole();
-
         // С󥳥ޥ
-        if ($data->is('h') || $data->is('-help')) {
+        if ($data->is('h') || $data->is('help')) {
             $this->displayHelp($cmd, $data->get(0));
             return;
         // إץޥ
-        } else if ($data->is('v') || $data->is('-version')) {
+        } else if ($data->is('v') || $data->is('version')) {
             $this->displayVersion($cmd, $data->get(0));
             return;
         }
 
         // ץȥǥ쥯ȥѥ᡼
-        $project_dir = $data->get('d');
-        if (is_array($project_dir) && (count($project_dir) > 0)) {
-            $project_dir = $project_dir[0];
-        } else {
+        $project_dir = $data->geta('d', 0);
+        if (!$project_dir) {
              $this->displayDefault($cmd, $data->get(0));
              return;
         }
-
-        // ץꥱ̾ѥ᡼
-        $app_name = $data->get('w');
-        if (is_array($app_name) && (count($app_name) > 0)) {
-            $app_name = $app_name[0];
-        } else {
-             $this->displayDefault($cmd, $data->get(0));
-             return;
-        }
-
-        // ǥ쥯ȥѥ᡼
-        $action_name = $data->get('a');
-        if (is_array($action_name) && (count($action_name) > 0)) {
-            $action_name = $action_name[0];
-        } else {
-            $action_name = '';
-        }
-
-        // ȥѥ᡼
-        $controller_file = $data->get('c');
-        $controller_dir  = '';
-        if (is_array($controller_file) && (count($controller_file) > 0)) {
-            $controller_dir = dirname($controller_file[0]);
-        }
-
-        // ơ֥ѥ᡼
-        $tablename = $data->get('t');
-        if (is_array($tablename) && (count($tablename) > 0)) {
-            $tablename = $tablename[0];
-        } else {
-             $this->displayDefault($cmd, $data->get(0));
-             return;
-        }
-
-        // Smartyѥ᡼
-        $smarty_flag = is_array($data->get('s'));
-
         if (!is_dir($project_dir)) {
             trigger_error("[SyL error] Project directory not found ({$project_dir})", E_USER_ERROR);
         }
 
+        // ץꥱ̾ѥ᡼
+        $app_name = $data->geta('w', 0);
+        if (!$app_name) {
+             $this->displayDefault($cmd, $data->get(0));
+             return;
+        }
+        $app_dir = "{$project_dir}/apps/{$app_name}"; 
+        if (!is_dir($app_dir)) {
+            trigger_error("[SyL error] Application directory not found ({$app_dir})", E_USER_ERROR);
+        }
+
+        // ǥ쥯ȥѥ᡼
+        $action_name = $data->geta('a', 0);
+        // ȥѥ᡼
+        $controller_dir = dirname($data->geta('c', 0));
+
+        // ơ֥ѥ᡼
+        $tablename = $data->geta('t', 0);
+        if (!$tablename) {
+             $this->displayDefault($cmd, $data->get(0));
+             return;
+        }
+        // Smartyѥ᡼
+        $smarty_flag = $data->is('s');
+
         $mkdirs = array();
 
         // -------------------------------------------------
         // ץȥǥ쥯ȥå
         // -------------------------------------------------
-        $cmd->stdout("  project application directory checking..."); ob_flush();
-
-        $app_dir = "{$project_dir}/apps/{$app_name}"; 
-        if (!is_dir($app_dir)) {
-            trigger_error("[SyL error] Application directory not found ({$app_dir})", E_USER_ERROR);
-        }
+        $cmd->stdout("  project application directory checking...");
 
         $action_dir   = '';
         $template_dir = '';
@@ -197,7 +177,7 @@ class Index extends AppAction
         // -------------------------------------------------
         // ơ֥ǥ쥯ȥå
         // -------------------------------------------------
-        $cmd->stdout("  project lib table directory checking..."); ob_flush();
+        $cmd->stdout("  project lib table directory checking...");
 
         $table_file  = $project_dir . '/lib';
         $table_class = $this->table_dir . ucfirst($tablename);
@@ -233,7 +213,7 @@ class Index extends AppAction
         // -------------------------------------------------
         // եǥ쥯ȥå
         // -------------------------------------------------
-        $cmd->stdout("  project lib form directory checking..."); ob_flush();
+        $cmd->stdout("  project lib form directory checking...");
 
         $form_file  = $project_dir . '/lib';
         $form_class = $this->form_dir . ucfirst($tablename);
@@ -272,7 +252,7 @@ class Index extends AppAction
         $image_dir = '';
         $css_dir   = '';
         if ($controller_dir) {
-            $cmd->stdout("  images or css directory checking..."); ob_flush();
+            $cmd->stdout("  images or css directory checking...");
 
             $image_dir = "{$controller_dir}/images";
             if (file_exists($image_dir)) {
@@ -314,7 +294,7 @@ class Index extends AppAction
         // -------------------------------------------------
         // ơ֥륹޼
         // -------------------------------------------------
-        $cmd->stdout("  table schema scaning..."); ob_flush();
+        $cmd->stdout("  table schema scaning...");
 
         // ơ֥륹޼
         $conn =& SyL_DB::getConnection();
@@ -332,7 +312,7 @@ class Index extends AppAction
         // -------------------------------------------------
         // ѿ˥å
         // -------------------------------------------------
-        $cmd->stdout("  valiables setting..."); ob_flush();
+        $cmd->stdout("  valiables setting...");
 
         $tables   = array();
         $columns  = array();
@@ -453,11 +433,11 @@ class Index extends AppAction
         // -------------------------------------------------
         // ǥ쥯ȥ
         // -------------------------------------------------
-        $cmd->stdout("  create directories..."); ob_flush();
+        $cmd->stdout("  create directories...");
 
         foreach ($mkdirs as $dir) {
             if (!file_exists($dir)) {
-                $cmd->stdout("  create directory {$dir}"); ob_flush();
+                $cmd->stdout("  create directory {$dir}");
                 mkdir($dir);
             }
         }
@@ -465,22 +445,22 @@ class Index extends AppAction
         // -------------------------------------------------
         // ե
         // -------------------------------------------------
-        $cmd->stdout("  create files..."); ob_flush();
+        $cmd->stdout("  create files...");
 
         // ƥץ졼ȥե
         $template_table_file     = SYL_PROJECT_DIR . '/var/templates/Table.php';
         $template_form_file      = SYL_PROJECT_DIR . '/var/templates/Form.php';
 
         // ơ֥ե
-        $cmd->stdout("  table template file {$template_table_file}"); ob_flush();
-        $cmd->stdout("    => generating table file {$table_file}"); ob_flush();
+        $cmd->stdout("  table template file {$template_table_file}");
+        $cmd->stdout("    -> generating table file {$table_file}");
 
         $file =& SyL_File::factory('w', $table_file);
         $file->process(str_replace($table_search, $table_replace, file_get_contents($template_table_file)));
 
         // եե
-        $cmd->stdout("  form template file {$template_form_file}"); ob_flush();
-        $cmd->stdout("    => generating form file {$form_file}"); ob_flush();
+        $cmd->stdout("  form template file {$template_form_file}");
+        $cmd->stdout("    -> generating form file {$form_file}");
 
         $file =& SyL_File::factory('w', $form_file);
         $file->process(str_replace($form_search, $form_replace, file_get_contents($template_form_file)));
@@ -489,56 +469,56 @@ class Index extends AppAction
             // ե
             $template_file = SYL_PROJECT_DIR . '/var/templates/actions/Index.php';
             $create_file   = "{$action_dir}/" . basename($template_file);
-            $cmd->stdout("  action template file {$template_file}"); ob_flush();
-            $cmd->stdout("    => generating form file {$create_file}"); ob_flush();
+            $cmd->stdout("  action template file {$template_file}");
+            $cmd->stdout("    -> generating form file {$create_file}");
 
             $file =& SyL_File::factory('w', $create_file);
             $file->process(str_replace($form_opp_search, $form_opp_replace, file_get_contents($template_file)));
 
             $template_file = SYL_PROJECT_DIR . '/var/templates/actions/Lst.php';
             $create_file   = "{$action_dir}/" . basename($template_file);
-            $cmd->stdout("  action template file {$template_file}"); ob_flush();
-            $cmd->stdout("    => generating form file {$create_file}"); ob_flush();
+            $cmd->stdout("  action template file {$template_file}");
+            $cmd->stdout("    -> generating form file {$create_file}");
 
             $file =& SyL_File::factory('w', $create_file);
             $file->process(str_replace($form_opp_search, $form_opp_replace, file_get_contents($template_file)));
 
             $template_file = SYL_PROJECT_DIR . '/var/templates/actions/New.php';
             $create_file   = "{$action_dir}/" . basename($template_file);
-            $cmd->stdout("  action template file {$template_file}"); ob_flush();
-            $cmd->stdout("    => generating form file {$create_file}"); ob_flush();
+            $cmd->stdout("  action template file {$template_file}");
+            $cmd->stdout("    -> generating form file {$create_file}");
 
             $file =& SyL_File::factory('w', $create_file);
             $file->process(str_replace($form_opp_search, $form_opp_replace, file_get_contents($template_file)));
 
             $template_file = SYL_PROJECT_DIR . '/var/templates/actions/Upd.php';
             $create_file   = "{$action_dir}/" . basename($template_file);
-            $cmd->stdout("  action template file {$template_file}"); ob_flush();
-            $cmd->stdout("    => generating form file {$create_file}"); ob_flush();
+            $cmd->stdout("  action template file {$template_file}");
+            $cmd->stdout("    -> generating form file {$create_file}");
 
             $file =& SyL_File::factory('w', $create_file);
             $file->process(str_replace($form_opp_search, $form_opp_replace, file_get_contents($template_file)));
 
             $template_file = SYL_PROJECT_DIR . '/var/templates/actions/Del.php';
             $create_file   = "{$action_dir}/" . basename($template_file);
-            $cmd->stdout("  action template file {$template_file}"); ob_flush();
-            $cmd->stdout("    => generating form file {$create_file}"); ob_flush();
+            $cmd->stdout("  action template file {$template_file}");
+            $cmd->stdout("    -> generating form file {$create_file}");
 
             $file =& SyL_File::factory('w', $create_file);
             $file->process(str_replace($form_opp_search, $form_opp_replace, file_get_contents($template_file)));
 
             $template_file = SYL_PROJECT_DIR . '/var/templates/actions/Fin.php';
             $create_file   = "{$action_dir}/" . basename($template_file);
-            $cmd->stdout("  action template file {$template_file}"); ob_flush();
-            $cmd->stdout("    => generating form file {$create_file}"); ob_flush();
+            $cmd->stdout("  action template file {$template_file}");
+            $cmd->stdout("    -> generating form file {$create_file}");
 
             $file =& SyL_File::factory('w', $create_file);
             $file->process(str_replace($form_opp_search, $form_opp_replace, file_get_contents($template_file)));
 
             $template_file = SYL_PROJECT_DIR . '/var/templates/actions/Vew.php';
             $create_file   = "{$action_dir}/" . basename($template_file);
-            $cmd->stdout("  action template file {$template_file}"); ob_flush();
-            $cmd->stdout("    => generating form file {$create_file}"); ob_flush();
+            $cmd->stdout("  action template file {$template_file}");
+            $cmd->stdout("    -> generating form file {$create_file}");
 
             $file =& SyL_File::factory('w', $create_file);
             $file->process(str_replace($form_opp_search, $form_opp_replace, file_get_contents($template_file)));
@@ -548,40 +528,40 @@ class Index extends AppAction
 
             $template_file = SYL_PROJECT_DIR . "/var/templates/templates/{$dir}/Lst.html";
             $create_file   = "{$template_dir}/" . basename($template_file);
-            $cmd->stdout("  template template file {$template_file}"); ob_flush();
-            $cmd->stdout("    => generating form file {$create_file}"); ob_flush();
+            $cmd->stdout("  template template file {$template_file}");
+            $cmd->stdout("    -> generating form file {$create_file}");
 
             $file =& SyL_File::factory('w', $create_file);
             $file->process(file_get_contents($template_file));
 
             $template_file = SYL_PROJECT_DIR . "/var/templates/templates/{$dir}/New.html";
             $create_file   = "{$template_dir}/" . basename($template_file);
-            $cmd->stdout("  template template file {$template_file}"); ob_flush();
-            $cmd->stdout("    => generating form file {$create_file}"); ob_flush();
+            $cmd->stdout("  template template file {$template_file}");
+            $cmd->stdout("    -> generating form file {$create_file}");
 
             $file =& SyL_File::factory('w', $create_file);
             $file->process(file_get_contents($template_file));
 
             $template_file = SYL_PROJECT_DIR . "/var/templates/templates/{$dir}/Upd.html";
             $create_file   = "{$template_dir}/" . basename($template_file);
-            $cmd->stdout("  template template file {$template_file}"); ob_flush();
-            $cmd->stdout("    => generating form file {$create_file}"); ob_flush();
+            $cmd->stdout("  template template file {$template_file}");
+            $cmd->stdout("    -> generating form file {$create_file}");
 
             $file =& SyL_File::factory('w', $create_file);
             $file->process(file_get_contents($template_file));
 
             $template_file = SYL_PROJECT_DIR . "/var/templates/templates/{$dir}/Fin.html";
             $create_file   = "{$template_dir}/" . basename($template_file);
-            $cmd->stdout("  template template file {$template_file}"); ob_flush();
-            $cmd->stdout("    => generating form file {$create_file}"); ob_flush();
+            $cmd->stdout("  template template file {$template_file}");
+            $cmd->stdout("    -> generating form file {$create_file}");
 
             $file =& SyL_File::factory('w', $create_file);
             $file->process(file_get_contents($template_file));
 
             $template_file = SYL_PROJECT_DIR . "/var/templates/templates/{$dir}/Vew.html";
             $create_file   = "{$template_dir}/" . basename($template_file);
-            $cmd->stdout("  template template file {$template_file}"); ob_flush();
-            $cmd->stdout("    => generating form file {$create_file}"); ob_flush();
+            $cmd->stdout("  template template file {$template_file}");
+            $cmd->stdout("    -> generating form file {$create_file}");
 
             $file =& SyL_File::factory('w', $create_file);
             $file->process(file_get_contents($template_file));
@@ -593,8 +573,8 @@ class Index extends AppAction
             if ($dh = opendir($dir)) {
                 while (($file = readdir($dh)) !== false) {
                     if (($file != '.') && ($file != '..')) {
-                        $cmd->stdout("  copying file {$dir}/{$file}"); ob_flush();
-                        $cmd->stdout("    => {$image_dir}/{$file}"); ob_flush();
+                        $cmd->stdout("  copying file {$dir}/{$file}");
+                        $cmd->stdout("    -> {$image_dir}/{$file}");
                         copy("{$dir}/{$file}", "{$image_dir}/{$file}");
                     }
                 }
@@ -608,8 +588,8 @@ class Index extends AppAction
             if ($dh = opendir($dir)) {
                 while (($file = readdir($dh)) !== false) {
                     if (($file != '.') && ($file != '..')) {
-                        $cmd->stdout("  copying file {$dir}/{$file}"); ob_flush();
-                        $cmd->stdout("    => {$css_dir}/{$file}"); ob_flush();
+                        $cmd->stdout("  copying file {$dir}/{$file}");
+                        $cmd->stdout("    -> {$css_dir}/{$file}");
                         copy("{$dir}/{$file}", "{$css_dir}/{$file}");
                     }
                 }
@@ -621,27 +601,27 @@ class Index extends AppAction
         // ɽ
         // -------------------------------------------------
 
-        $cmd->stdout(""); ob_flush();
-        $cmd->stdout("--- Result ---"); ob_flush();
-        $cmd->stdout("  [project directory] {$project_dir}"); ob_flush();
+        $cmd->stdout("");
+        $cmd->stdout("--- Result ---");
+        $cmd->stdout("  [project directory] {$project_dir}");
         if ($action_name) {
-            $cmd->stdout("  [action directory] {$action_dir}"); ob_flush();
-            $cmd->stdout("  [template directory] {$template_dir}"); ob_flush();
+            $cmd->stdout("  [action directory] {$action_dir}");
+            $cmd->stdout("  [template directory] {$template_dir}");
         }
-        $cmd->stdout("  [table name] {$tablename}"); ob_flush();
-        $cmd->stdout("  [form class] {$form_file}"); ob_flush();
-        $cmd->stdout("  [table class] {$table_file}"); ob_flush();
+        $cmd->stdout("  [table name] {$tablename}");
+        $cmd->stdout("  [form class] {$form_file}");
+        $cmd->stdout("  [table class] {$table_file}");
         if ($image_dir) {
-            $cmd->stdout("  [images directory] {$image_dir}"); ob_flush();
+            $cmd->stdout("  [images directory] {$image_dir}");
         }
         if ($css_dir) {
-            $cmd->stdout("  [css directory] {$css_dir}"); ob_flush();
+            $cmd->stdout("  [css directory] {$css_dir}");
         }
 
         if ($action_name) {
             $action_name = '/' . strtolower($action_name);
-            $cmd->stdout("--- URL ---"); ob_flush();
-            $cmd->stdout("  http://(hostname)/(controller_file){$action_name}/"); ob_flush();
+            $cmd->stdout("--- URL ---");
+            $cmd->stdout("  http://(hostname)/(controller_file){$action_name}/");
         }
     }
 
