@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: Index.php,v 1.2 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: Index.php,v 1.3 2008/07/10 15:17:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: Index.php,v 1.2 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: Index.php,v 1.3 2008/07/10 15:17:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class Index extends AppAction
@@ -50,15 +50,6 @@ class Index extends AppAction
     var $c_template; // 󥸥
     var $c_project; // 󥸥
 
-    /**
-     * 󥹥ȥ饯
-     *
-     * @access public
-     */
-    function Index()
-    {
-    }
-
     /**
      * ᥤ
      *
@@ -80,7 +71,7 @@ class Index extends AppAction
             $obj->c_controller  =& $this->c_controller;
             $obj->c_template    =& $this->c_template;
             $obj->c_project     =& $this->c_project;
-            $obj->execute($data, &$context);
+            $obj->execute($data, $context);
             break;
         case 'application':
         case 'app':
@@ -90,33 +81,35 @@ class Index extends AppAction
             $obj->c_application =& $this->c_application;
             $obj->c_controller  =& $this->c_controller;
             $obj->c_template    =& $this->c_template;
-            $obj->execute($data, &$context);
+            $obj->execute($data, $context);
             break;
         case 'controller':
         case 'con':
             include_once 'Controller.php';
             $obj =& new Controller();
             $obj->c_controller =& $this->c_controller;
+            $obj->execute($data, $context);
             break;
         case 'action':
         case 'act':
             include_once 'Action.php';
             $obj =& new Action();
             $obj->c_action =& $this->c_action;
-            $obj->execute($data, &$context);
+            $obj->execute($data, $context);
             break;
         case 'template':
         case 'tem':
             include_once 'Template.php';
             $obj =& new Template();
             $obj->c_template =& $this->c_template;
+            $obj->execute($data, $context);
             break;
         default:
             // С󥳥ޥ
-            if ($data->is('h') || $data->is('-help')) {
+            if ($data->is('h') || $data->is('help')) {
                 $this->displayHelp($cmd, $data->get(0));
             // إץޥ
-            } else if ($data->is('v') || $data->is('-version')) {
+            } else if ($data->is('v') || $data->is('version')) {
                 $this->displayVersion($cmd, $data->get(0));
             } else {
                 $this->displayDefault($cmd, $data->get(0));
