@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: CreateAction.php,v 1.3 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: CreateAction.php,v 1.4 2008/07/10 15:17:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: CreateAction.php,v 1.3 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: CreateAction.php,v 1.4 2008/07/10 15:17:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class CreateAction
@@ -48,15 +48,16 @@ class CreateAction
      * ե
      *
      * @access public
+     * @param object 󥽡륪֥
      * @param string ץȥǥ쥯ȥ
      * @param string ץꥱ̾
      * @param string ե
      */
-    function trigger($project_dir, $app_name, $action_file)
+    function trigger(&$cmd, $project_dir, $app_name, $action_file)
     {
         $action_dir = "{$project_dir}apps/{$app_name}/actions/";
         if (!is_dir($action_dir)) {
-            echo "  creating directory {$action_dir}\n"; ob_flush();
+            $cmd->stdout("  -> creating directory {$action_dir}");
             if (!mkdir($action_dir, 0755)) {
                 trigger_error("[SyL error] action directory can't create ({$action_dir})", E_USER_ERROR);
                 exit;
@@ -97,12 +98,12 @@ class CreateAction
 
             foreach ($create_dir as $dir) {
                 if (!is_dir($dir)) {
-                    echo "  creating directory {$dir}\n"; ob_flush();
+                    $cmd->stdout("  -> creating directory {$dir}");
                     mkdir($dir, 0755);
                 }
             }
 
-            echo "  creating file {$file}\n"; ob_flush();
+            $cmd->stdout("  -> creating file {$file}");
             $fp = fopen($file, 'wb');
             fwrite($fp, $contents_tmp);
             fclose($fp);
