@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: CreateApplication.php,v 1.5 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: CreateApplication.php,v 1.6 2008/07/10 15:17:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: CreateApplication.php,v 1.5 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: CreateApplication.php,v 1.6 2008/07/10 15:17:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class CreateApplication
@@ -48,14 +48,15 @@ class CreateApplication
      * ץꥱǥ쥯ȥ
      *
      * @access public
+     * @param object 󥽡륪֥
      * @param string ץȥǥ쥯ȥ
      * @param string ץꥱ̾
      */
-    function trigger($project_dir, $app_name)
+    function trigger(&$cmd, $project_dir, $app_name)
     {
         $app_dir = "{$project_dir}apps/{$app_name}/";
         if (!is_dir($app_dir)) {
-            echo "  creating directory {$app_dir}\n"; ob_flush();
+            $cmd->stdout("  -> creating directory {$app_dir}");
             if (!mkdir($app_dir, 0755)) {
                 trigger_error("[SyL error] Application directory can't create ({$app_dir})", E_USER_ERROR);
                 exit;
@@ -82,14 +83,14 @@ class CreateApplication
 
         foreach ($dirs as $dir => $mode) {
             if (!is_dir($app_dir . $dir)) {
-                echo "  creating directory {$app_dir}{$dir}\n"; ob_flush();
+                $cmd->stdout("  -> creating directory {$app_dir}{$dir}");
                 mkdir("{$app_dir}{$dir}");
                 chmod("{$app_dir}{$dir}", $mode);
             }
         }
 
         foreach ($files as $file_org => $file_dist) {
-            echo "  copying file {$app_dir}{$file_dist}\n"; ob_flush();
+            $cmd->stdout("  -> copying file {$app_dir}{$file_dist}");
             if (file_exists("{$project_dir}var/skel-templates/{$file_org}")) {
                 copy("{$project_dir}var/skel-templates/{$file_org}", "{$app_dir}{$file_dist}");
             } else {
