@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: CreateController.php,v 1.2 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: CreateController.php,v 1.3 2008/07/10 15:17:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: CreateController.php,v 1.2 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: CreateController.php,v 1.3 2008/07/10 15:17:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class CreateController
@@ -48,11 +48,12 @@ class CreateController
      * ȥե
      *
      * @access public
+     * @param object 󥽡륪֥
      * @param string ץȥǥ쥯ȥ
      * @param string ץꥱ̾
      * @param string ȥե
      */
-    function trigger($project_dir, $app_name, $controller_file)
+    function trigger(&$cmd, $project_dir, $app_name, $controller_file)
     {
         if (preg_match('/(\\\\|\/)$/', $project_dir)) {
             $project_dir = substr($project_dir, 0, -1);
@@ -68,7 +69,7 @@ class CreateController
         );
         $contents = strtr($contents, $trans);
 
-        echo "  creating file {$controller_file}\n"; ob_flush();
+        $cmd->stdout("  -> creating file {$controller_file}");
         $fp = fopen($controller_file, 'wb');
         fwrite($fp, $contents);
         fclose($fp);
