@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: CreateProject.php,v 1.3 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: CreateProject.php,v 1.4 2008/07/10 15:17:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: CreateProject.php,v 1.3 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: CreateProject.php,v 1.4 2008/07/10 15:17:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class CreateProject
@@ -48,9 +48,10 @@ class CreateProject
      * ץȥǥ쥯ȥ
      *
      * @access public
+     * @param object 󥽡륪֥
      * @param string ץȥǥ쥯ȥ
      */
-    function trigger($project_dir)
+    function trigger(&$cmd, $project_dir)
     {
         if (!is_dir($project_dir)) {
             if (!mkdir($project_dir, 0755)) {
@@ -85,14 +86,14 @@ class CreateProject
 
         foreach ($dirs as $dir => $mode) {
             if (!is_dir($project_dir . $dir)) {
-                echo "  creating directory {$project_dir}{$dir}\n"; ob_flush();
+                $cmd->stdout("  -> creating directory {$project_dir}{$dir}");
                 mkdir("{$project_dir}{$dir}");
                 chmod("{$project_dir}{$dir}", $mode);
             }
         }
 
         foreach ($files as $file_org => $file_dist) {
-            echo "  copying file {$project_dir}{$file_dist}\n"; ob_flush();
+            $cmd->stdout("  -> copying file {$project_dir}{$file_dist}");
             if (file_exists("{$project_dir}var/skel-templates/{$file_org}")) {
                 copy("{$project_dir}var/skel-templates/{$file_org}", "{$project_dir}{$file_dist}");
             } else {
@@ -104,7 +105,7 @@ class CreateProject
         while (($file = readdir($dh)) !== false) {
             if ($file != '.' && $file != '..') {
                 $basefile = $file;
-                echo "  copying file {$project_dir}var/skel-templates/{$file}\n"; ob_flush();
+                $cmd->stdout("  -> copying file {$project_dir}var/skel-templates/{$file}");
                 copy(SYL_PROJECT_DIR . "/var/skel-templates/{$file}", "{$project_dir}var/skel-templates/{$file}");
             }
         }
