@@ -6,7 +6,7 @@
  * @package   {APP_NAME}
  * @author    {author}
  * @copyright {copyright}
- * @version   $Id: AppAction.php,v 1.3 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   $Id: AppAction.php,v 1.4 2008/06/20 17:41:54 seasonstream Exp $
  */
 class AppAction extends SyL_Action
 {
@@ -19,6 +19,19 @@ class AppAction extends SyL_Action
      */
     function preExecute(&$data, &$context)
     {
+        parent::preExecute($data, $context);
+    }
+
+    /**
+     * ᥽åɼ¹˼¹Ԥ븡ڥ᥽å
+     * 
+     * @access public
+     * @param object ǡ֥
+     * @param object ƥȥ֥
+     */
+    function validate(&$data, &$context)
+    {
+        parent::validate($data, $context);
     }
 
     /**
@@ -30,6 +43,7 @@ class AppAction extends SyL_Action
      */
     function postExecute(&$data, &$context)
     {
+        parent::postExecute($data, $context);
     }
 }
 
