@@ -6,19 +6,10 @@
  * @package   {APP_NAME}
  * @author    {author}
  * @copyright {copyright}
- * @version   $Id: action.php,v 1.3 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   $Id: action.php,v 1.4 2008/07/10 15:17:43 seasonstream Exp $
  */
 class {SYL_CLASS} extends AppAction
 {
-    /**
-     * 󥹥ȥ饯
-     *
-     * @access public
-     */
-    function {SYL_CLASS}()
-    {
-    }
-
     /**
      * ǥեȥ
      *
